.. _ground state:

=============
Ground States
=============

Classes to perform ground-state searches.

.. automodule:: smol.capp.generate.groundstate.upper_bound.solver
   :members:
   :undoc-members:
   :show-inheritance:
   :exclude-members: ProblemCanonicals
